# peppy python package

[![Build Status](https://travis-ci.org/pepkit/peppy.svg?branch=master)](https://travis-ci.org/pepkit/peppy)
[![Coverage Status](https://coveralls.io/repos/github/pepkit/peppy/badge.svg?branch=master)](https://coveralls.io/github/pepkit/peppy?branch=master)
[![PEP compatible](http://pepkit.github.io/img/PEP-compatible-green.svg)](http://pepkit.github.io)

`peppy` is the official python package for reading **Portable Encapsulated Projects** or **PEP**s in `python`. 

Links to complete documentation:

* Complete documentation and API for the `peppy` python package is at [peppy.databio.org](http://peppy.databio.org).
* Reference documentation for standard **PEP** format is at [pepkit.github.io](https://pepkit.github.io/).
* Example PEPs for testing `peppy` are in the [example_peps repository](https://github.com/pepkit/example_peps).
